==> jc-1.4.0.tar.gz: gnu/classpath/SystemProperties.h <==
// public class gnu.classpath.SystemProperties

// class file dependencies
// @dep_class c3e37402f8a0600b gnu_classpath_SystemProperties
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_classpath_SystemProperties_H_
#define _JC_gnu_classpath_SystemProperties_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Properties$object;

// Typedefs
typedef struct _jc_gnu_classpath_SystemProperties$sub_refs	_jc_gnu_classpath_SystemProperties$sub_refs;
typedef struct _jc_gnu_classpath_SystemProperties$sub_nonrefs	_jc_gnu_classpath_SystemProperties$sub_nonrefs;
typedef struct _jc_gnu_classpath_SystemProperties$refs	_jc_gnu_classpath_SystemProperties$refs;
typedef struct _jc_gnu_classpath_SystemProperties$nonrefs	_jc_gnu_classpath_SystemProperties$nonrefs;
typedef struct _jc_gnu_classpath_SystemProperties$object	_jc_gnu_classpath_SystemProperties$object;

typedef struct _jc_gnu_classpath_SystemProperties$fields_struct	_jc_gnu_classpath_SystemProperties$fields_struct;
typedef const struct _jc_gnu_classpath_SystemProperties$vmethods	_jc_gnu_classpath_SystemProperties$vmethods;
typedef const struct _jc_gnu_classpath_SystemProperties$vtable	_jc_gnu_classpath_SystemProperties$vtable;
typedef const struct _jc_gnu_classpath_SystemProperties$vtype	_jc_gnu_classpath_SystemProperties$vtype;

// Class fields structure
struct _jc_gnu_classpath_SystemProperties$fields_struct {
	struct _jc_java_util_Properties$object	*defaultProperties;
	struct _jc_java_util_Properties$object	*properties;
};
extern _jc_gnu_classpath_SystemProperties$fields_struct _jc_gnu_classpath_SystemProperties$class_fields;

// Constructors
extern void _jc_gnu_classpath_SystemProperties$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_classpath_SystemProperties$object *);

// Static methods
extern void _jc_gnu_classpath_SystemProperties$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_util_Properties$object *_jc_gnu_classpath_SystemProperties$method$getProperties$f9217c122caadf9a(_jc_env *);
extern struct _jc_java_lang_String$object *_jc_gnu_classpath_SystemProperties$method$getProperty$17fb18205ea95f87(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_classpath_SystemProperties$method$getProperty$5c51978e044a69cc(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);
extern void _jc_gnu_classpath_SystemProperties$method$setProperties$e9d891cb9ff83937(_jc_env *, struct _jc_java_util_Properties$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_classpath_SystemProperties$method$setProperty$35052149c6edaf78(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_gnu_classpath_SystemProperties$vmethods {
};

// Vtable
struct _jc_gnu_classpath_SystemProperties$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_classpath_SystemProperties$vmethods	gnu_classpath_SystemProperties;
};

// Vtype
struct _jc_gnu_classpath_SystemProperties$vtype {
	_jc_type			type;
	_jc_gnu_classpath_SystemProperties$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_classpath_SystemProperties$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_classpath_SystemProperties$refs {
    _jc_gnu_classpath_SystemProperties$sub_refs	gnu_classpath_SystemProperties;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_classpath_SystemProperties$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_classpath_SystemProperties$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_classpath_SystemProperties$sub_nonrefs	gnu_classpath_SystemProperties;
};

// Object instance structure
struct _jc_gnu_classpath_SystemProperties$object {
	_jc_gnu_classpath_SystemProperties$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_classpath_SystemProperties$vtype	*vtype;
	_jc_gnu_classpath_SystemProperties$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_classpath_SystemProperties$vtype _jc_gnu_classpath_SystemProperties$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_classpath_SystemProperties, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_classpath_SystemProperties$class_object;

#endif	/* _JC_gnu_classpath_SystemProperties_H_ */

==> jc-1.4.5.tar.gz: gnu/classpath/SystemProperties.h <==
// public class gnu.classpath.SystemProperties

// class file dependencies
// @dep_class bd462333576bb02 gnu_classpath_SystemProperties
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_classpath_SystemProperties_H_
#define _JC_gnu_classpath_SystemProperties_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Properties$object;

// Typedefs
typedef struct _jc_gnu_classpath_SystemProperties$sub_refs	_jc_gnu_classpath_SystemProperties$sub_refs;
typedef struct _jc_gnu_classpath_SystemProperties$sub_nonrefs	_jc_gnu_classpath_SystemProperties$sub_nonrefs;
typedef struct _jc_gnu_classpath_SystemProperties$refs	_jc_gnu_classpath_SystemProperties$refs;
typedef struct _jc_gnu_classpath_SystemProperties$nonrefs	_jc_gnu_classpath_SystemProperties$nonrefs;
typedef struct _jc_gnu_classpath_SystemProperties$object	_jc_gnu_classpath_SystemProperties$object;

typedef struct _jc_gnu_classpath_SystemProperties$fields_struct	_jc_gnu_classpath_SystemProperties$fields_struct;
typedef const struct _jc_gnu_classpath_SystemProperties$vmethods	_jc_gnu_classpath_SystemProperties$vmethods;
typedef const struct _jc_gnu_classpath_SystemProperties$vtable	_jc_gnu_classpath_SystemProperties$vtable;
typedef const struct _jc_gnu_classpath_SystemProperties$vtype	_jc_gnu_classpath_SystemProperties$vtype;

// Class fields structure
struct _jc_gnu_classpath_SystemProperties$fields_struct {
	struct _jc_java_util_Properties$object	*defaultProperties;
	struct _jc_java_util_Properties$object	*properties;
};
extern _jc_gnu_classpath_SystemProperties$fields_struct _jc_gnu_classpath_SystemProperties$class_fields;

// Constructors
extern void _jc_gnu_classpath_SystemProperties$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_classpath_SystemProperties$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_gnu_classpath_SystemProperties$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_util_Properties$object *_jc_gnu_classpath_SystemProperties$method$getProperties$f9217c122caadf9a(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_classpath_SystemProperties$method$getProperty$17fb18205ea95f87(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_classpath_SystemProperties$method$getProperty$5c51978e044a69cc(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_classpath_SystemProperties$method$setProperties$e9d891cb9ff83937(_jc_env *, struct _jc_java_util_Properties$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_classpath_SystemProperties$method$setProperty$35052149c6edaf78(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_classpath_SystemProperties$vmethods {
};

// Vtable
struct _jc_gnu_classpath_SystemProperties$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_classpath_SystemProperties$vmethods	gnu_classpath_SystemProperties;
};

// Vtype
struct _jc_gnu_classpath_SystemProperties$vtype {
	_jc_type			type;
	_jc_gnu_classpath_SystemProperties$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_classpath_SystemProperties$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_classpath_SystemProperties$refs {
    _jc_gnu_classpath_SystemProperties$sub_refs	gnu_classpath_SystemProperties;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_classpath_SystemProperties$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_classpath_SystemProperties$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_classpath_SystemProperties$sub_nonrefs	gnu_classpath_SystemProperties;
};

// Object instance structure
struct _jc_gnu_classpath_SystemProperties$object {
	_jc_gnu_classpath_SystemProperties$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_classpath_SystemProperties$vtype	*vtype;
	_jc_gnu_classpath_SystemProperties$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_classpath_SystemProperties$vtype _jc_gnu_classpath_SystemProperties$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_classpath_SystemProperties, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_classpath_SystemProperties$class_object;

#endif	/* _JC_gnu_classpath_SystemProperties_H_ */
